============
Installation
============

At the command line::

    $ pip install yasmine-cli

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv yasmine-cli
    $ pip install yasmine-cli
